@@ -1,6 +1,6 @@
 package Treex::Block::W2A::EN::FixTokenization;
 {
-  $Treex::Block::W2A::EN::FixTokenization::VERSION = '0.07297';
+  $Treex::Block::W2A::EN::FixTokenization::VERSION = '0.08057';
 }
 use Moose;
 use Treex::Core::Common;
@@ -11,6 +11,7 @@ my %MERGE_FOR = (
     'p . m .' => 'p. m.',
     'U . S .' => 'U. S.',
     'e . g .' => 'e. g.',
+    'i . e .' => 'i. e.',
     'Mrs .'   => 'Mrs.',
     'Mr .'    => 'Mr.',
     'Ms .'    => 'Ms.',
@@ -53,6 +54,8 @@ sub process_atree {
             #warn "merging $merged\n";
             $nodes[$i]->set_form($merged);
             $nodes[$i]->set_attr( 'gloss', 'merged' );
+            $nodes[$i]->set_no_space_after( $nodes[ $i + $length ]->no_space_after );
+            
             foreach my $node ( @nodes[ $i + 1 .. $i + $length ] ) {
                 $node->remove();
             }
@@ -74,7 +77,7 @@ Treex::Block::W2A::EN::FixTokenization - fix some issues in output of tokenizer
 
 =head1 VERSION
 
-version 0.07297
+version 0.08057
 
 =head1 DESCRIPTION
 
